﻿using System;
using System.Collections.Generic;
using System.Text;

namespace Vortex.Drawing {

	/// <summary>
	/// Contains information about char/glyph of sprite font
	/// </summary>
	public class SpriteCharInfo {
		private char _code;
		private Sprite _glyph;
		private Vector2 _size;

		/// <summary>
		/// Initializes a new instance of the <see cref="SpriteCharInfo"/>.
		/// </summary>
		/// <param name="code">The code.</param>
		/// <param name="sprite">The sprite with this char.</param>
		/// <param name="size">The overall size of char.</param>
		public SpriteCharInfo(char code, Sprite glyph, Vector2 size) {
			_code = code;
			_glyph = glyph;
			_size = size;
		}

		/// <summary>
		/// Gets the code of this char.
		/// </summary>
		/// <value>The char code.</value>
		public char Code {
			get { return _code; }
		}

		/// <summary>
		/// Gets the original region of glyph onto glyphs texture.
		/// </summary>
		/// <value>The region rectangle.</value>
		public Sprite Glyph {
			get { return _glyph; }
		}

		/// <summary>
		/// Gets the size of char in display units.
		/// </summary>
		/// <value>The size of char.</value>
		public Vector2 Size {
			get { return _size; }
		}


	}
}
